==> netwib-5.38.0.txz: usr/local/include/netwib538/def.h <==
#define NETWIBDEF_SYSNAME_Unix 1
#define NETWIBDEF_SYSNAME "FreeBSD"
#define NETWIBDEF_SYSNAME_FreeBSD 1
#define NETWIBDEF_SYSARCH "arm"
#define NETWIBDEF_SYSARCH_arm 1
#define NETWIBDEF_ARCH_ENDIAN 0
#define NETWIBDEF_ARCH_BITS 32
#define NETWIBDEF_ARCH_ALIGN 1
#define NETWIBDEF_VERSION "5.38.0"
#define NETWIBDEF_VERSIONMAJOR 5
#define NETWIBDEF_VERSIONMINOR 38
#define NETWIBDEF_VERSIONMICRO 0
#define NETWIBDEF_LIBPTHREADINSTALLED 1
#define NETWIBDEF_LIBPTHREADFROMDCE 0
#define NETWIBDEF_LIBPTHREADFROMMIT 0
#define NETWIBDEF_LIBPCAPINSTALLED 1
#define NETWIBDEF_LIBPCAPFROMREDHAT 1
#define NETWIBDEF_LIBNETINSTALLED 1
#define NETWIBDEF_LIBNETVERSION11 1
#define NETWIBDEF_LIBUTILINSTALLED 0
#define NETWIBDEF_PROGCC "cc"
#define NETWIBDEF_PROGCCALIAS 1
#define NETWIBDEF_PROGCCWUNDEF 1
#define NETWIBDEF_PROGCCWSIGNC 1
#define NETWIBDEF_PROGCCWEXTRA 1
#define NETWIBDEF_PROGAR "ar"
#define NETWIBDEF_PROGRANLIB "ranlib"
#define NETWIBDEF_PROGGREP "grep"
#define NETWIBDEF_INSTPREFIX "/usr/local"
#define NETWIBDEF_INSTINCLUDE "/usr/local/include"
#define NETWIBDEF_INSTLIB "/usr/local/lib"
#define NETWIBDEF_INSTBIN "/usr/local/bin"
#define NETWIBDEF_INSTMAN "/usr/local/man"
#define NETWIBDEF_INSTMAN3 "/usr/local/man/man3"
#define NETWIBDEF_SUPPORT_SNIFF 1
#define NETWIBDEF_SUPPORT_SPOOF 1
#define NETWIBDEF_SUPPORT_ENCODETYPE_PCAP 1
#define NETWIBDEF_TYPE_INT8 char
#define NETWIBDEF_TYPE_UINT8 unsigned char
#define NETWIBDEF_TYPE_INT16 short
#define NETWIBDEF_TYPE_UINT16 unsigned short
#define NETWIBDEF_TYPE_INT32 int
#define NETWIBDEF_TYPE_UINT32 unsigned int
#define NETWIBDEF_TYPE_INT64 long long
#define NETWIBDEF_TYPE_UINT64 unsigned long long
#define NETWIBDEF_TYPE_INT64_FAKE 0
#define NETWIBDEF_HAVEINCL_PTHREAD 1
#define NETWIBDEF_HAVEINCL_STROPTS 0
#define NETWIBDEF_HAVEINCL_SCHED 1
#define NETWIBDEF_HAVEINCL_PTY 0
#define NETWIBDEF_HAVEINCL_SYS_POLL 1
#define NETWIBDEF_HAVEINCL_SYS_PARAM 1
#define NETWIBDEF_HAVEINCL_SYS_SYSCTL 1
#define NETWIBDEF_HAVEINCL_SYS_IOCTL 1
#define NETWIBDEF_HAVEINCL_SYS_SOCKIO 1
#define NETWIBDEF_HAVEINCL_SYS_DLPI 0
#define NETWIBDEF_HAVEINCL_SYS_BUFMOD 0
#define NETWIBDEF_HAVEINCL_SYS_MMAN 1
#define NETWIBDEF_HAVEINCL_NET_ETHERNET 1
#define NETWIBDEF_HAVEINCL_NET_IF_ARP 1
#define NETWIBDEF_HAVEINCL_NET_IF_TYPES 1
#define NETWIBDEF_HAVEINCL_NET_IF_DL 1
#define NETWIBDEF_HAVEINCL_NET_BPF 1
#define NETWIBDEF_HAVEINCL_NETINET_IF_ETHER 1
#define NETWIBDEF_HAVEINCL_NETINET_ETHER 0
#define NETWIBDEF_HAVEINCL_NETPACKET_PACKET 0
#define NETWIBDEF_HAVEINCL_ASM_PAGE 0
#define NETWIBDEF_HAVEINCL_MACH_MACHINE_VMPARAM 0
#define NETWIBDEF_HAVEINCL_MACHINE_PARAM 1
#define NETWIBDEF_HAVETYPE_SIZE_T 1
#define NETWIBDEF_HAVETYPE_SOCKLEN_T 1
#define NETWIBDEF_HAVETYPE_SIGHANDLER_T 0
#define NETWIBDEF_HAVETYPE_SIG_T 1
#define NETWIBDEF_HAVETYPE_OFF_T 1
#define NETWIBDEF_HAVETYPE_PTHREAD_RWLOCK_T 1
#define NETWIBDEF_HAVETYPE_SOCKADDR_IN6 1
#define NETWIBDEF_HAVEFIELD_TM_GMTOFF 1
#define NETWIBDEF_HAVEFIELD_SOCKADDR_SALEN 1
#define NETWIBDEF_HAVEFIELD_SOCKADDRIN_SINLEN 1
#define NETWIBDEF_HAVEFIELD_SOCKADDRIN6_SIN6LEN 1
#define NETWIBDEF_HAVEFUNC_ETHER_NTOHOST 1
#define NETWIBDEF_HAVEFUNC_ETHER_HOSTTON 1
#define NETWIBDEF_HAVEFUNC_HSTRERROR 1
#define NETWIBDEF_HAVEFUNC_SNPRINTF 1
#define NETWIBDEF_HAVEFUNC_PCAP_FREECODE 1
#define NETWIBDEF_HAVEFUNC_PCAP_FREECODE2 0
#define NETWIBDEF_HAVEFUNC_PCAP_OPENDEAD 1
#define NETWIBDEF_HAVEFUNC_POLL 1
#define NETWIBDEF_HAVEFUNC_DIRFD 1
#define NETWIBDEF_HAVEFUNC_FPATHCONF 1
#define NETWIBDEF_HAVEFUNC_PATHCONF 1
#define NETWIBDEF_HAVEFUNC_SYSCONF 1
#define NETWIBDEF_HAVEFUNC_GETPAGESIZE 1
#define NETWIBDEF_HAVEFUNC_GETRLIMIT 1
#define NETWIBDEF_HAVEFUNC_NANOSLEEP 1
#define NETWIBDEF_HAVEFUNC_USLEEP 1
#define NETWIBDEF_HAVEFUNC_GETTIMEOFDAY 1
#define NETWIBDEF_HAVEFUNC_CLOCK_GETTIME 1
#define NETWIBDEF_HAVEFUNC_PTHREAD_DELAY_NP 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_MUTEX_TIMEDLOCK 1
#define NETWIBDEF_HAVEFUNC_PTHREAD_RWLOCK_TIMEDRDLOCK 1
#define NETWIBDEF_HAVEFUNC_PTHREAD_RWLOCK_TIMEDWRLOCK 1
#define NETWIBDEF_HAVEFUNC_PTHREAD_YIELD 1
#define NETWIBDEF_HAVEFUNC_SCHED_YIELD 1
#define NETWIBDEF_HAVEFUNC_GETPWNAM_R 1
#define NETWIBDEF_HAVEFUNC_GETGRNAM_R 1
#define NETWIBDEF_HAVEFUNC_GETGRGID_R 1
#define NETWIBDEF_HAVEFUNC_READDIR_R 1
#define NETWIBDEF_HAVEFUNC_GETHOSTBYNAME_R 1
#define NETWIBDEF_HAVEFUNC_GETHOSTBYADDR_R 1
#define NETWIBDEF_HAVEFUNC_GETNAMEINFO 1
#define NETWIBDEF_HAVEFUNC_GETADDRINFO 1
#define NETWIBDEF_HAVEFUNC_GETIPNODEBYNAME 1
#define NETWIBDEF_HAVEFUNC_GETIPNODEBYADDR 1
#define NETWIBDEF_HAVEFUNC_LOCALTIME_R 1
#define NETWIBDEF_HAVEVAR_HERRNO 1
#define NETWIBDEF_HAVEVAR_PATH_MAX 1
#define NETWIBDEF_HAVEVAR_NAME_MAX 1
#define NETWIBDEF_HAVEVAR_PAGE_SIZE 1
#define NETWIBDEF_HAVEVAR_PAGESIZE 0
#define NETWIBDEF_HAVEVAR_BIOCSHDRCMPLT 1
#define NETWIBDEF_HAVEVAR_SIOCGLIFCONF 0
#define NETWIBDEF_HAVEVAR_AF_INET6 1
#define NETWIBDEF_HAVEVAR_SC_GETPW_R_SIZE_MAX 1
#define NETWIBDEF_HAVEVAR_SC_GETGR_R_SIZE_MAX 1

==> netwib-5.38.0_1.txz: usr/local/include/netwib538/def.h <==
#define NETWIBDEF_SYSNAME_Unix 1
#define NETWIBDEF_SYSNAME "FreeBSD"
#define NETWIBDEF_SYSNAME_FreeBSD 1
#define NETWIBDEF_SYSARCH "ia64"
#define NETWIBDEF_SYSARCH_ia64 1
#define NETWIBDEF_ARCH_ENDIAN 0
#define NETWIBDEF_ARCH_BITS 64
#define NETWIBDEF_ARCH_ALIGN 1
#define NETWIBDEF_VERSION "5.38.0"
#define NETWIBDEF_VERSIONMAJOR 5
#define NETWIBDEF_VERSIONMINOR 38
#define NETWIBDEF_VERSIONMICRO 0
#define NETWIBDEF_LIBPTHREADINSTALLED 1
#define NETWIBDEF_LIBPTHREADFROMDCE 0
#define NETWIBDEF_LIBPTHREADFROMMIT 0
#define NETWIBDEF_LIBPCAPINSTALLED 1
#define NETWIBDEF_LIBPCAPFROMREDHAT 1
#define NETWIBDEF_LIBNETINSTALLED 1
#define NETWIBDEF_LIBNETVERSION11 1
#define NETWIBDEF_LIBUTILINSTALLED 0
#define NETWIBDEF_PROGCC "cc"
#define NETWIBDEF_PROGCCALIAS 1
#define NETWIBDEF_PROGCCWUNDEF 1
#define NETWIBDEF_PROGCCWSIGNC 1
#define NETWIBDEF_PROGCCWEXTRA 1
#define NETWIBDEF_PROGAR "ar"
#define NETWIBDEF_PROGRANLIB "ranlib"
#define NETWIBDEF_PROGGREP "grep"
#define NETWIBDEF_INSTPREFIX "/usr/local"
#define NETWIBDEF_INSTINCLUDE "/usr/local/include"
#define NETWIBDEF_INSTLIB "/usr/local/lib"
#define NETWIBDEF_INSTBIN "/usr/local/bin"
#define NETWIBDEF_INSTMAN "/usr/local/man"
#define NETWIBDEF_INSTMAN3 "/usr/local/man/man3"
#define NETWIBDEF_SUPPORT_SNIFF 1
#define NETWIBDEF_SUPPORT_SPOOF 1
#define NETWIBDEF_SUPPORT_ENCODETYPE_PCAP 1
#define NETWIBDEF_TYPE_INT8 char
#define NETWIBDEF_TYPE_UINT8 unsigned char
#define NETWIBDEF_TYPE_INT16 short
#define NETWIBDEF_TYPE_UINT16 unsigned short
#define NETWIBDEF_TYPE_INT32 int
#define NETWIBDEF_TYPE_UINT32 unsigned int
#define NETWIBDEF_TYPE_INT64 long
#define NETWIBDEF_TYPE_UINT64 unsigned long
#define NETWIBDEF_TYPE_INT64_FAKE 0
#define NETWIBDEF_HAVEINCL_PTHREAD 1
#define NETWIBDEF_HAVEINCL_STROPTS 0
#define NETWIBDEF_HAVEINCL_SCHED 1
#define NETWIBDEF_HAVEINCL_PTY 0
#define NETWIBDEF_HAVEINCL_SYS_POLL 1
#define NETWIBDEF_HAVEINCL_SYS_PARAM 1
#define NETWIBDEF_HAVEINCL_SYS_SYSCTL 1
#define NETWIBDEF_HAVEINCL_SYS_IOCTL 1
#define NETWIBDEF_HAVEINCL_SYS_SOCKIO 1
#define NETWIBDEF_HAVEINCL_SYS_DLPI 0
#define NETWIBDEF_HAVEINCL_SYS_BUFMOD 0
#define NETWIBDEF_HAVEINCL_SYS_MMAN 1
#define NETWIBDEF_HAVEINCL_NET_ETHERNET 1
#define NETWIBDEF_HAVEINCL_NET_IF_ARP 1
#define NETWIBDEF_HAVEINCL_NET_IF_TYPES 1
#define NETWIBDEF_HAVEINCL_NET_IF_DL 1
#define NETWIBDEF_HAVEINCL_NET_BPF 1
#define NETWIBDEF_HAVEINCL_NETINET_IF_ETHER 1
#define NETWIBDEF_HAVEINCL_NETINET_ETHER 0
#define NETWIBDEF_HAVEINCL_NETPACKET_PACKET 0
#define NETWIBDEF_HAVEINCL_ASM_PAGE 0
#define NETWIBDEF_HAVEINCL_MACH_MACHINE_VMPARAM 0
#define NETWIBDEF_HAVEINCL_MACHINE_PARAM 1
#define NETWIBDEF_HAVETYPE_SIZE_T 1
#define NETWIBDEF_HAVETYPE_SOCKLEN_T 1
#define NETWIBDEF_HAVETYPE_SIGHANDLER_T 0
#define NETWIBDEF_HAVETYPE_SIG_T 1
#define NETWIBDEF_HAVETYPE_OFF_T 1
#define NETWIBDEF_HAVETYPE_PTHREAD_RWLOCK_T 1
#define NETWIBDEF_HAVETYPE_SOCKADDR_IN6 1
#define NETWIBDEF_HAVEFIELD_TM_GMTOFF 1
#define NETWIBDEF_HAVEFIELD_SOCKADDR_SALEN 1
#define NETWIBDEF_HAVEFIELD_SOCKADDRIN_SINLEN 1
#define NETWIBDEF_HAVEFIELD_SOCKADDRIN6_SIN6LEN 1
#define NETWIBDEF_HAVEFUNC_ETHER_NTOHOST 1
#define NETWIBDEF_HAVEFUNC_ETHER_HOSTTON 1
#define NETWIBDEF_HAVEFUNC_HSTRERROR 1
#define NETWIBDEF_HAVEFUNC_SNPRINTF 1
#define NETWIBDEF_HAVEFUNC_PCAP_FREECODE 1
#define NETWIBDEF_HAVEFUNC_PCAP_FREECODE2 0
#define NETWIBDEF_HAVEFUNC_PCAP_OPENDEAD 1
#define NETWIBDEF_HAVEFUNC_POLL 1
#define NETWIBDEF_HAVEFUNC_DIRFD 1
#define NETWIBDEF_HAVEFUNC_FPATHCONF 1
#define NETWIBDEF_HAVEFUNC_PATHCONF 1
#define NETWIBDEF_HAVEFUNC_SYSCONF 1
#define NETWIBDEF_HAVEFUNC_GETPAGESIZE 1
#define NETWIBDEF_HAVEFUNC_GETRLIMIT 1
#define NETWIBDEF_HAVEFUNC_NANOSLEEP 1
#define NETWIBDEF_HAVEFUNC_USLEEP 1
#define NETWIBDEF_HAVEFUNC_GETTIMEOFDAY 1
#define NETWIBDEF_HAVEFUNC_CLOCK_GETTIME 1
#define NETWIBDEF_HAVEFUNC_PTHREAD_DELAY_NP 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_MUTEX_TIMEDLOCK 1
#define NETWIBDEF_HAVEFUNC_PTHREAD_RWLOCK_TIMEDRDLOCK 1
#define NETWIBDEF_HAVEFUNC_PTHREAD_RWLOCK_TIMEDWRLOCK 1
#define NETWIBDEF_HAVEFUNC_PTHREAD_YIELD 1
#define NETWIBDEF_HAVEFUNC_SCHED_YIELD 1
#define NETWIBDEF_HAVEFUNC_GETPWNAM_R 1
#define NETWIBDEF_HAVEFUNC_GETGRNAM_R 1
#define NETWIBDEF_HAVEFUNC_GETGRGID_R 1
#define NETWIBDEF_HAVEFUNC_READDIR_R 1
#define NETWIBDEF_HAVEFUNC_GETHOSTBYNAME_R 1
#define NETWIBDEF_HAVEFUNC_GETHOSTBYADDR_R 1
#define NETWIBDEF_HAVEFUNC_GETNAMEINFO 1
#define NETWIBDEF_HAVEFUNC_GETADDRINFO 1
#define NETWIBDEF_HAVEFUNC_GETIPNODEBYNAME 1
#define NETWIBDEF_HAVEFUNC_GETIPNODEBYADDR 1
#define NETWIBDEF_HAVEFUNC_LOCALTIME_R 1
#define NETWIBDEF_HAVEVAR_HERRNO 1
#define NETWIBDEF_HAVEVAR_PATH_MAX 1
#define NETWIBDEF_HAVEVAR_NAME_MAX 1
#define NETWIBDEF_HAVEVAR_PAGE_SIZE 1
#define NETWIBDEF_HAVEVAR_PAGESIZE 0
#define NETWIBDEF_HAVEVAR_BIOCSHDRCMPLT 1
#define NETWIBDEF_HAVEVAR_SIOCGLIFCONF 0
#define NETWIBDEF_HAVEVAR_AF_INET6 1
#define NETWIBDEF_HAVEVAR_SC_GETPW_R_SIZE_MAX 1
#define NETWIBDEF_HAVEVAR_SC_GETGR_R_SIZE_MAX 1
